@@ -11,6 +11,7 @@ __all__ = [
     "ManagerBasedPermission",
     "ReadOnlyInterface",
     "Rule",
+    "get_logger",
     "graph_ql_mutation",
     "graph_ql_property",
 ]
@@ -23,5 +24,6 @@ from general_manager.manager.input import Input
 from general_manager.permission.manager_based_permission import ManagerBasedPermission
 from general_manager.interface.read_only_interface import ReadOnlyInterface
 from general_manager.rule.rule import Rule
+from general_manager.logging import get_logger
 from general_manager.api.mutation import graph_ql_mutation
 from general_manager.api.property import graph_ql_property
