@@ -10,6 +10,6 @@ __all__ = [
 ]
 
 from general_manager.measurement.measurement import Measurement
-from general_manager.measurement.measurementField import MeasurementField
+from general_manager.measurement.measurement_field import MeasurementField
 from general_manager.measurement.measurement import currency_units
 from general_manager.measurement.measurement import ureg
