@@ -1,21 +1,18 @@
 """Helpers for generating realistic factory values for Django models."""
 
 from __future__ import annotations
-from typing import TYPE_CHECKING, Any, cast
+from typing import Any, cast
 
 from factory.declarations import LazyFunction
 from factory.faker import Faker
 import exrex  # type: ignore[import-untyped]
 from django.core.validators import RegexValidator
 from django.db import models
-from datetime import date, datetime, time, timezone
+from datetime import date, datetime, time, timezone, timedelta
 from decimal import Decimal
 from random import SystemRandom
 from general_manager.measurement.measurement import Measurement
-from general_manager.measurement.measurementField import MeasurementField
-
-if TYPE_CHECKING:
-    from general_manager.factory.autoFactory import AutoFactory
+from general_manager.measurement.measurement_field import MeasurementField
 
 
 _RNG = SystemRandom()
@@ -65,7 +62,7 @@ class InvalidRelatedModelTypeError(TypeError):
         )
 
 
-def getFieldValue(
+def get_field_value(
     field: models.Field[Any, Any] | models.ForeignObjectRel,
 ) -> Any:
     """
@@ -158,7 +155,7 @@ def getFieldValue(
     elif isinstance(field, models.UUIDField):
         return cast(str, Faker("uuid4"))
     elif isinstance(field, models.DurationField):
-        return cast(time, Faker("time_delta"))
+        return cast(timedelta, Faker("time_delta"))
     elif isinstance(field, models.CharField):
         max_length = field.max_length or 100
         # Check for RegexValidator
@@ -173,7 +170,7 @@ def getFieldValue(
         else:
             return cast(str, Faker("text", max_nb_chars=max_length))
     elif isinstance(field, models.OneToOneField):
-        related_model = getRelatedModel(field)
+        related_model = get_related_model(field)
         if hasattr(related_model, "_general_manager_class"):
             related_factory = related_model._general_manager_class.Factory  # type: ignore
             return related_factory()
@@ -185,7 +182,7 @@ def getFieldValue(
             else:
                 raise MissingFactoryOrInstancesError(related_model)
     elif isinstance(field, models.ForeignKey):
-        related_model = getRelatedModel(field)
+        related_model = get_related_model(field)
         # Create or get an instance of the related model
         if hasattr(related_model, "_general_manager_class"):
             create_a_new_instance = _RNG.choice([True, True, False])
@@ -209,7 +206,7 @@ def getFieldValue(
         return None
 
 
-def getRelatedModel(
+def get_related_model(
     field: models.ForeignObjectRel | models.Field[Any, Any],
 ) -> type[models.Model]:
     """
@@ -239,7 +236,7 @@ def getRelatedModel(
     return cast(type[models.Model], related_model)
 
 
-def getManyToManyFieldValue(
+def get_many_to_many_field_value(
     field: models.ManyToManyField,
 ) -> list[models.Model]:
     """
@@ -257,7 +254,7 @@ def getManyToManyFieldValue(
         MissingFactoryOrInstancesError: If the related model provides neither a factory nor any existing instances.
     """
     related_factory = None
-    related_model = getRelatedModel(field)
+    related_model = get_related_model(field)
     related_instances = list(related_model.objects.all())
     if hasattr(related_model, "_general_manager_class"):
         related_factory = related_model._general_manager_class.Factory  # type: ignore
