@@ -10,13 +10,13 @@ from django.core.exceptions import ValidationError
 
 
 if TYPE_CHECKING:
-    from general_manager.manager.generalManager import GeneralManager
+    from general_manager.manager.general_manager import GeneralManager
     from general_manager.rule.rule import Rule
 
 modelsModel = TypeVar("modelsModel", bound=models.Model)
 
 
-def getFullCleanMethode(model: Type[models.Model]) -> Callable[..., None]:
+def get_full_clean_methode(model: Type[models.Model]) -> Callable[..., None]:
     """
     Return a custom `full_clean` method for a Django model that performs both standard validation and additional rule-based checks.
 
@@ -44,7 +44,7 @@ def getFullCleanMethode(model: Type[models.Model]) -> Callable[..., None]:
         rules: list[Rule] = getattr(self._meta, "rules", [])
         for rule in rules:
             if rule.evaluate(self) is False:
-                error_message = rule.getErrorMessage()
+                error_message = rule.get_error_message()
                 if error_message:
                     errors.update(error_message)
 
