@@ -1,7 +1,12 @@
-SECRET_KEY = "test-secret-key"
+from django.utils.crypto import get_random_string
+
+
+SECRET_KEY = get_random_string(50)
 DEBUG = True
 
 INSTALLED_APPS = [
+    "channels",
+    "graphene_django",
     "django.contrib.auth",
     "django.contrib.contenttypes",
     "django.contrib.sessions",
@@ -20,6 +25,8 @@ DATABASES = {
 AUTOCREATE_GRAPHQL = True
 SESSION_ENGINE = "django.contrib.sessions.backends.signed_cookies"
 ROOT_URLCONF = "tests.test_urls"
+GRAPHQL_URL = "graphql/"
+ASGI_APPLICATION = "tests.testing_asgi.application"
 
 MIDDLEWARE = [
     # ggf. noch andere Middleware …
